@@ -16,7 +16,7 @@
 ; along with this program; if not, write to the Free Software Foundation,
 ; Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 ;
-; $Id: oracle.lisp,v 1.24 2005/11/17 23:09:56 sds Exp $
+; $Id: oracle.lisp,v 1.25 2006/05/30 11:35:10 hin Exp $
 
 (defpackage "ORACLE"
   (:documentation
@@ -784,7 +784,10 @@ Argument: none
 				   (setf *read-default-float-format* 'double-float)
 				   (read-from-string val))
 			   (setf *read-default-float-format* old-default-format))))
-          ((find dtype '("VARCHAR" "DATE" "CHAR" "VARCHAR2" "LONG" "RAW" "LONG RAW" "CLOB" "ROWID DESC") :test #'equal)
+          ((find dtype '("VARCHAR" "DATE" "CHAR" "VARCHAR2" "LONG" "RAW" "LONG RAW" "CLOB" "ROWID DESC"
+                         "ANSI DATE" "TIME" "TIME WITH TIME ZONE" "TIMESTAMP" "TIMESTAMP WITH TIME ZONE"
+                         "INTERVAL YEAR TO MONTH" "INTERVAL DAY TO SECOND" "TIMESTAMP WITH LOCAL TZ"
+                         ) :test #'equal)
            val)
           (t (db-error (cat "Unsupported data type '" dtype "'"))))))
 
