@@ -19,7 +19,7 @@
    along with this program; if not, write to the Free Software Foundation,
    Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
-   $Id: orafns.c,v 1.15 2005/05/20 20:03:51 haible Exp $
+   $Id: orafns.c,v 1.19 2006-06-19 13:50:06 hin Exp $
 
 */
 
@@ -79,6 +79,7 @@ static int       check_active_statement(struct db_conn *, char *);
 static int       check_active_select(struct db_conn *, char *);
 static int       empty(char *);
 static char *    valid_string(char *);
+static void      hexify (unsigned char *, int) ;
 
 /* Static indicator variables for input data */
 static sb4      null_indicator = -1;
@@ -403,8 +404,12 @@ static int fetch_row(struct db_conn * db)
 			return db->success = 0;
 		  }
 		
-		  /* Null-terminate the data buffer */
-		  ((char *) col->data)[minof(act_nread, db->long_len)] = '\0';
+                  /* For BLOB or BFILE, convert to hex */
+                  if ( col->dtype == SQLT_BLOB || col->dtype == SQLT_BFILE )
+                    hexify((unsigned char *) col->data, act_nread);
+                  else
+                    /* Null-terminate the data buffer */
+                    ((char *) col->data)[minof(act_nread, db->long_len)] = '\0';
 		}
 	}
     else if ( col->indicator == -1 )
@@ -1126,8 +1131,18 @@ static char * decode_data_type(int dtype)
   case 113: return "BLOB";                 /* SQLT_BLOB - Binary LOB */
   case 114: return "BFILE";                /* SQLT_BFILEE - Binary file LOB */
   case 115: return "CFILE";                /* SQLT_CFILEE - Character file LOB */
+
+  /* datetimes and intervals */
+  case 184: return "ANSI DATE";                /* SQLT_DATE */
+  case 185: return "TIME";                     /* SQLT_TIME */
+  case 186: return "TIME WITH TIME ZONE";      /* SQLT_TIME_TZ */
+  case 187: return "TIMESTAMP";                /* SQLT_TIMESTAMP */
+  case 188: return "TIMESTAMP WITH TIME ZONE"; /* SQLT_TIMESTAMP_TZ */
+  case 189: return "INTERVAL YEAR TO MONTH";   /* SQLT_INTERVAL_YM */
+  case 190: return "INTERVAL DAY TO SECOND";   /* SQLT_INTERVAL_DS */
+  case 232: return "TIMESTAMP WITH LOCAL TZ";  /* SQLT_TIMESTAMP_LTZ */
   }
-  sprintf("<Unknown type %d>", buf);
+  sprintf(buf, "<Unknown type %d>", dtype);
   return buf;
 }
 
@@ -1153,19 +1168,23 @@ static int fetch_data_len(int dtype, int dlen, int long_len)
   case 96:  /* CHAR (SQLT_AFC) */
     return dlen + 1;
     
+	/* Use 1000 for numbers so that very large/small floats will never be truncated */
   case 2:   /* NUMBER (SQLT_NUM) */
   case 3:   /* INTEGER (SQLT_INT) */
   case 4:   /* FLOAT (SQLT_FLT) */
-    return 50;
+    return 1000;
     
   case 104: /* ROWID DESC (SQLT_RDD) */
 	return 50;
 
   case 8:   /* LONG (SQLT_LNG) */
   case 112: /* CLOB (SQLT_CLOB) */
+    return long_len + 1;
+    
+	/* Use twice long_len for BLOBs so we can convert to hex */
   case 113: /* BLOB (SQLT_BLOB) */
   case 114: /* BFILE (SQLT_FILE) */
-    return long_len + 1;
+    return 2 * long_len + 1;
 
   case 24:  /* LONG RAW (SQLT_LBI) */
     return 2 * long_len + 1;
@@ -1175,6 +1194,18 @@ static int fetch_data_len(int dtype, int dlen, int long_len)
     
   case 12:  /* DATE (SQLT_DAT) */
     return 50;
+
+  /* datetimes and intervals */
+  case 184: /* SQLT_DATE */
+  case 185: /* SQLT_TIME */
+  case 186: /* SQLT_TIME_TZ */
+  case 187: /* SQLT_TIMESTAMP */
+  case 188: /* SQLT_TIMESTAMP_TZ */
+  case 189: /* SQLT_INTERVAL_YM */
+  case 190: /* SQLT_INTERVAL_DS */
+  case 232: /* SQLT_TIMESTAMP_LTZ */
+    return 200;
+
   }
   return 0;
 }
@@ -1214,6 +1245,10 @@ static int disconnect(struct db_conn * db)
 
   free_columns(db);
   
+  /* Tell the server we are disconnecting */
+  if ( db->svc )
+    OCILogoff(db->svc, db->err);
+
   /* This should cause Oracle to free up all other handles created under it */
   if ( db->env )
     OCIHandleFree(db->env, OCI_HTYPE_ENV);
@@ -1426,6 +1461,24 @@ static int empty(char * s) { return !s || !*s; }
 /* Map NULL to empty string */
 static char * valid_string(char * s) { return s ? s : ""; }
 
+/* Convert a binary buffer to null-terminated hex in place.  Actual
+   allocation of buf must be twice N plus 1.  Work from the end to the
+   start so we don't stomp on ourselves. */
+/* Convert int to hex */
+#define itoh(n)(((n) > 9) ? ((n) - 10 + 'A') : ((n) + '0'))
+static void hexify (unsigned char * buf, int n) 
+{
+  int i;
+  for ( i = n-1; i >= 0; i-- ) {
+	unsigned char c = buf[i];
+    buf[2*i] = itoh(c / 16);
+    buf[2*i + 1] = itoh(c & 0xF);
+  }
+
+  /* Null terminate */
+  buf[2*n] = '\0';
+}
+
 /* ------------------------------------------------------------------------------------------------------------- */
 
 /* Wrapper routines - these are part of the "void *" based interface
