@@ -87,10 +87,10 @@ The keyword argument REPEAT specifies how many objects to read:
 
 ;;; see also clocc/cllib/net.lisp
 (defvar *http-proxy* nil
-  "A list of 3 elements (user:password host port), parsed from $HTTP_PROXY
+  "A list of 3 elements (user:password host port), parsed from $http_proxy
 proxy-user:proxy-password@proxy-host:proxy-port")
 (defconstant *http-port* 80)
-(defun http-proxy (&optional (proxy-string (getenv "HTTP_PROXY") proxy-p))
+(defun http-proxy (&optional (proxy-string (getenv "http_proxy") proxy-p))
   "When the argument is supplied or *HTTP-PROXY* is NIL, parse the argument,
 set *HTTP-PROXY*, and return it; otherwise just return *HTTP-PROXY*."
   (when (or proxy-p (and (null *http-proxy*) proxy-string))
@@ -186,6 +186,24 @@ set *HTTP-PROXY*, and return it; otherwise just return *HTTP-PROXY*."
                     (setq content-length (parse-integer line :start #6#))))
           :finally (terpri)))
     (values sock content-length)))
+(defun open-url (path &rest options &aux (len (length path)))
+  (cond ((string-equal #1="http://" path :end2 (min len #.(length #1#)))
+         (apply #'open-http path options))
+        ((string-equal #2="file:/" path :end2 (min len #3=#.(length #2#)))
+         (apply #'open (subseq path (position #\/ path :test-not #'eql
+                                              :start #3#))
+                options))
+        (t (open path))))
+
+;;; the CLHS & IMPNOTES documentation:
+;; * symbols (and packages for IMPNOTES) can have a doc string that points
+;;   to the position of the documentation text in the CLHS or IMPNOTES.
+;; * (documentation foo 'sys::clhs) and (documentation foo 'sys::impnotes)
+;;   return a valid URL that can be printed or passed to the browser
+;; * (setf (documentation foo 'sys::clhs) "bar") and
+;;   (setf (documentation foo 'sys::impnotes) "bar")
+;;   "bar" is the URL sans (clhs-root) and (impnotes-root)
+
 (defun get-clhs-map (stream)
   "Download and install the CLHS map."
   (format t "~&;; ~S(~S)..." 'get-clhs-map stream) (force-output)
@@ -207,15 +225,11 @@ set *HTTP-PROXY*, and return it; otherwise just return *HTTP-PROXY*."
   ;; nil return value means no map exists
   (defun ensure-clhs-map ()
     "make sure that the CLHS map is present"
-    (let ((clhs-root (clhs-root)) opener)
+    (let ((clhs-root (clhs-root)))
       (when (and clhs-root (string/= clhs-map-source clhs-root))
-        (setq clhs-map-source clhs-root
-              opener (if (string-equal #1="http://" clhs-root
-                                       :end2 (min (length clhs-root)
-                                                  #.(length #1#)))
-                         #'open-http #'open))
-        (with-open-stream (s (or (funcall opener (string-concat clhs-root "Data/Map_Sym.txt") :if-does-not-exist nil)
-                                 (funcall opener (string-concat clhs-root "Data/Symbol-Table.text") :if-does-not-exist nil)))
+        (setq clhs-map-source clhs-root)
+        (with-open-stream (s (or (open-url (string-concat clhs-root "Data/Map_Sym.txt") :if-does-not-exist nil)
+                                 (open-url (string-concat clhs-root "Data/Symbol-Table.text") :if-does-not-exist nil)))
           (unless s
             (warn (TEXT "~S returns invalid value ~S, fix it, ~S, ~S, or ~S")
                   'clhs-root clhs-root '(getenv "CLHSROOT")
@@ -239,7 +253,8 @@ set *HTTP-PROXY*, and return it; otherwise just return *HTTP-PROXY*."
     (setf (gethash id table) destination)
     :finally (format t "~:D ID~:P~%" total))
   table)
-(let ((impnotes-map-source nil) (impnotes-map-good nil))
+(let ((impnotes-map-source nil) (impnotes-map-good nil)
+      (dest (lambda (id) (string-concat "#" id))))
   ;; if impnotes-map-source is the same as (impnotes-root), do nothing
   ;; and return (and impnotes-map-good (impnotes-root));
   ;; otherwise set impnotes-map-source to (impnotes-root) and try to get
@@ -247,28 +262,23 @@ set *HTTP-PROXY*, and return it; otherwise just return *HTTP-PROXY*."
   ;; nil return value means no map exists
   (defun ensure-impnotes-map (&optional check-symbol-map)
     "make sure that the impnotes map is present"
-    (let ((impnotes-root (impnotes-root))
-          (dest (lambda (id) (string-concat "#" id))))
+    (let ((impnotes-root (impnotes-root)))
       (when (and impnotes-root (string/= impnotes-map-source impnotes-root))
         (setq impnotes-map-source impnotes-root)
         (case (char impnotes-root (1- (length impnotes-root)))
           ((#\/ #+win32 #\\) ; chunked impnotes ==> get id-href
-           (let ((opener (if (string-equal #1="http://" impnotes-root
-                                           :end2 (min (length impnotes-root)
-                                                      #.(length #1#)))
-                             #'open-http #'open)))
-             (with-open-stream (s (funcall opener (string-concat impnotes-root
-                                                                 "id-href.map")
-                                           :if-does-not-exist nil))
-               (unless s
-                 #2=(warn (TEXT "~S returns invalid value ~S, fix it, ~S, ~S, or ~S")
-                          'impnotes-root impnotes-root '(getenv "IMPNOTES")
-                          '*impnotes-root-default* '*http-proxy*)
-                 (return-from ensure-impnotes-map))
-               (let ((table (get-string-map s)))
-                 (unless table   ; no table --> bail out
-                   #2# (return-from ensure-impnotes-map))
-                 (setq dest (lambda (id) (gethash id table))))))))
+           (with-open-stream (s (open-url (string-concat impnotes-root
+                                                         "id-href.map")
+                                          :if-does-not-exist nil))
+             (unless s
+               #2=(warn (TEXT "~S returns invalid value ~S, fix it, ~S, ~S, or ~S")
+                        'impnotes-root impnotes-root '(getenv "IMPNOTES")
+                        '*impnotes-root-default* '*http-proxy*)
+               (return-from ensure-impnotes-map))
+             (let ((table (get-string-map s)))
+               (unless table   ; no table --> bail out
+                 #2# (return-from ensure-impnotes-map))
+               (setq dest (lambda (id) (gethash id table)))))))
         (with-open-file (in (clisp-data-file "Symbol-Table.text"))
           (format t "~&;; ~S(~S)..." 'ensure-impnotes-map (truename in))
           (force-output)
@@ -292,7 +302,11 @@ set *HTTP-PROXY*, and return it; otherwise just return *HTTP-PROXY*."
                         'ensure-impnotes-map id symbol-printname)))
             :finally (format t "~:D ID~:P~%" count)))
         (setq impnotes-map-good t)) ; success
-      (and impnotes-map-good impnotes-root))))
+      (and impnotes-map-good impnotes-root)))
+  (defmethod documentation ((obj package) (type (eql 'sys::impnotes)))
+    (let ((doc (sys::package-documentation obj)))
+      (and (consp doc) (ensure-impnotes-map)
+           (string-concat (impnotes-root) (funcall dest (second doc)))))))
 
 (defmethod documentation ((obj symbol) (type (eql 'sys::clhs)))
   (when (and (eq (symbol-package obj) #,(find-package "CL")) (ensure-clhs-map))
@@ -300,14 +314,15 @@ set *HTTP-PROXY*, and return it; otherwise just return *HTTP-PROXY*."
       (when doc (string-concat (clhs-root) doc)))))
 
 (defmethod documentation ((obj symbol) (type (eql 'sys::impnotes)))
-  (when (ensure-impnotes-map)
-    (let ((doc (or (call-next-method)
-                   (documentation (symbol-package obj) 'sys::impnotes))))
-      (when doc (string-concat (impnotes-root) doc)))))
-
-(defmethod documentation ((obj package) (type (eql 'sys::impnotes)))
-  (let ((doc (sys::package-documentation obj)))
-    (and (consp doc) (second doc))))
+  (let ((pack (symbol-package obj)))
+    ;; do not search impnotes for user symbols
+    (when (and pack
+               (member (package-name pack) *system-package-list* :test #'equal)
+               (ensure-impnotes-map))
+      (let ((doc (call-next-method)))
+        (if doc
+          (string-concat (impnotes-root) doc)
+          (documentation pack 'sys::impnotes))))))
 
 (defmethod (setf documentation) (new-value (obj package)
                                  (type (eql 'sys::impnotes)))
@@ -323,12 +338,14 @@ set *HTTP-PROXY*, and return it; otherwise just return *HTTP-PROXY*."
 (setf (documentation (find-package "CS-CL-USER") 'sys::impnotes) "cs-clu")
 (setf (documentation (find-package "CS-CL") 'sys::impnotes) "package-case")
 #+screen (setf (documentation (find-package "SCREEN") 'sys::impnotes) "screen")
-(setf (documentation (find-package "SOCKET") 'sys::impnotes) "socket")
+#+sockets (setf (documentation (find-package "SOCKET") 'sys::impnotes) "socket")
 #+generic-streams
 (setf (documentation (find-package "GSTREAM") 'sys::impnotes) "gstream")
 (setf (documentation (find-package "I18N") 'sys::impnotes) "i18n")
+#+FFI
 (setf (documentation (find-package "FFI") 'sys::impnotes) "dffi")
 (setf (documentation (find-package "CUSTOM") 'sys::impnotes) "customize")
+#+UNICODE
 (setf (documentation (find-package "CHARSET") 'sys::impnotes) "charset")
 (setf (documentation (find-package "CLOS") 'sys::impnotes) "classes")
 (setf (documentation (find-package "EXT") 'sys::impnotes) "ext-pac")
