@@ -121,12 +121,12 @@
                 (pop iterstates)))
             (return nil))))))
 
-;; The list of packages that will be locked by SAVEINITMEM.
-;; Also the default packages to unlock by WITHOUT-PACKAGE-LOCK.
 (defvar *system-package-list*
-  '("SYSTEM" "LISP" "EXT" "CUSTOM" "I18N" "GRAY" "CHARSET" "CLOS"
+  '("SYSTEM" "COMMON-LISP" "EXT" "I18N" "GRAY" "CHARSET" "CLOS"
     #+sockets "SOCKET" #+generic-streams "GSTREAM" #+syscalls "POSIX"
-    #+ffi "FFI" #+(or) "AFFI" #+screen "SCREEN"))
+    #+ffi "FFI" #+(or) "AFFI" #+screen "SCREEN")
+  "The list of packages that will be locked by SAVEINITMEM.
+Also the default packages to unlock by WITHOUT-PACKAGE-LOCK.")
 
 ;; Unlock the specified packages, execute the BODY, then lock them again.
 (defmacro with-no-package-lock-internal (packages &body body)
@@ -487,67 +487,50 @@
                                (rest rule)))
                      translations)))
   ;; load many hosts from a file, AllegroCL-style
-  (defun load-lpt-many (file host)
+  (defun load-lpt-many (file host &aux (*load-level* (1+ *load-level*)))
     (with-open-file (fi file :if-does-not-exist nil)
       (unless fi (return-from load-lpt-many nil))
-      (when *load-verbose*
-        (fresh-line) (write-string ";; ")
-        (format t (TEXT "Loading logical hosts from file ~A ...") file)
-        (terpri))
-      (do* ((eof (gensym)) (host (read fi nil eof) (read fi nil eof)))
-           ((eq host eof)
-            (write-string ";; ")
-            (format t (TEXT "Loaded file ~A") file)
-            (terpri))
+      (loading-message (TEXT "Loading logical hosts from file ~A ...") file)
+      (do* ((eof fi) (host (read fi nil eof) (read fi nil eof)))
+           ((eq host eof) (loading-message (TEXT "Loaded file ~A") file))
         (setq host (string-upcase host))
         (set-logical-pathname-translations host (eval (read fi)))
-        (when *load-verbose*
-          (fresh-line) (write-string ";; ")
-          (format t (TEXT "Defined logical host ~A") host)
-          (terpri))))
+        (loading-message (TEXT "Defined logical host ~A") host)))
     (gethash host *logical-pathname-translations*))
   ;; load a single host from a file, CMUCL-style
-  (defun load-lpt-one (file host)
+  (defun load-lpt-one (file host &aux (*load-level* (1+ *load-level*)))
     (with-open-file (fi file :if-does-not-exist nil)
       (unless fi (return-from load-lpt-one nil))
-      (when *load-verbose*
-        (fresh-line) (write-string ";; ")
-        (format t (TEXT "Loading logical host ~S from file ~A ...") host file))
+      (loading-message (TEXT "Loading logical host from file ~A ...") file)
       (set-logical-pathname-translations host (read fi))
-      (when *load-verbose*
-        (write-string (TEXT " done"))
-        (terpri)))
+      (loading-message (TEXT "Defined logical host ~A") host))
     (gethash host *logical-pathname-translations*))
   (defun load-logical-pathname-translations (host)
     (setq host (string-upcase host))
     (unless (gethash host *logical-pathname-translations*) ; :test #'equal !
-      (let ((from (string-concat "LOGICAL_HOST_" host "_FROM"))
-            (to (string-concat "LOGICAL_HOST_" host "_TO"))
-            (ho (string-concat "LOGICAL_HOST_" host)))
+      (let ((from (string-concat #2="LOGICAL_HOST_" host "_FROM"))
+            (to (string-concat #2# host "_TO"))
+            (ho (string-concat #2# host)))
         (cond ((and (fboundp 'getenv) (getenv from) (getenv to))
-               (set-logical-pathname-translations host
-                 (list (list (getenv from) (getenv to)))))
+               (set-logical-pathname-translations
+                host (list (list (getenv from) (getenv to))))
+               (return-from load-logical-pathname-translations t))
               ((and (fboundp 'getenv) (getenv ho))
-               (set-logical-pathname-translations host
-                 (read-from-string (getenv ho))))
+               (set-logical-pathname-translations
+                host (read-from-string (getenv ho)))
+               (return-from load-logical-pathname-translations t))
               ((dolist (file *load-logical-pathname-translations-database*)
                  (if (pathname-name file)
-                   (progn       ; non-directory
-                     (when (load-lpt-many file host) ; successfully defined?
-                       (return-from load-logical-pathname-translations t))
-                     (dolist (ff (search-file file '("" "host")))
-                       (when (load-lpt-many ff host) ; successfully defined?
-                         (return-from load-logical-pathname-translations t))))
-                   (progn       ; directory
-                     (when (load-lpt-one (merge-pathnames
-                                          (string-downcase host) file)
-                                         host) ; successfully defined?
-                       (return-from load-logical-pathname-translations t))
-                     (dolist (ff (search-file file nil))
-                       (and (string-equal host (pathname-name ff))
-                            (load-lpt-one ff host) ; successfully defined?
-                            (return-from load-logical-pathname-translations
-                              t)))))))))
+                   (dolist (ff (search-file file '(nil "host")))
+                     (when (load-lpt-many ff host) ; successfully defined?
+                       (return-from load-logical-pathname-translations t)))
+                   (dolist (ff (search-file file nil))
+                     (and (string-equal host (pathname-name ff))
+                          (or (null (pathname-type ff))
+                              (string-equal "host" (pathname-type ff)))
+                          (load-lpt-one ff host) ; successfully defined?
+                          (return-from load-logical-pathname-translations
+                            t))))))))
       (error (TEXT "No translations for logical host ~S found") host)))
   (set-logical-pathname-translations "SYS"
     '((";*.LISP" "*.lisp") (";*" "*") ("*" "/*"))))
@@ -576,11 +559,11 @@
       (fresh-line stream)
       (write-string "Real time: " stream)
       (write (float (/ Real-Time internal-time-units-per-second)) :stream stream)
-      (write-string " sec." stream)
+      (write-string #1=" sec." stream)
       (terpri stream)
       (write-string "Run time: " stream)
       (write (float (/ Run-Time internal-time-units-per-second)) :stream stream)
-      (write-string " sec." stream)
+      (write-string #1# stream)
       (terpri stream)
       (write-string "Space: " stream)
       (write Space :stream stream)
@@ -590,7 +573,7 @@
         (write-string "GC: " stream) (write GC-Count :stream stream)
         (write-string ", GC time: " stream)
         (write (float (/ GC-Time internal-time-units-per-second)) :stream stream)
-        (write-string " sec." stream))
+        (write-string #1# stream))
       (elastic-newline stream))))
 
 ;; (sleep N) pause for N seconds. CLTL p. 447
@@ -721,21 +704,23 @@
 ; CLTL p. 446
 (defun encode-universal-time
               (Sekunde Minute Stunde Tag Monat Jahr &optional (Zeitzone nil)
-               &aux Monat3 Jahr3 Jahrtag UTTag)
+               &aux Monat3 Jahr3 Jahrtag UTTag UT)
   (unless (and (and (integerp Jahr)
                     (progn
                       (when (<= 0 Jahr 99)
-                        (multiple-value-bind (i1 i2 i3 i4 i5 Jahrjetzt) (get-decoded-time)
+                        (multiple-value-bind (i1 i2 i3 i4 i5 Jahrjetzt)
+                            (get-decoded-time)
                           (declare (ignore i1 i2 i3 i4 i5))
                           (setq Jahr
-                            (+ Jahr (* 100 (ceiling (- Jahrjetzt Jahr 50) 100))))))
-                      (<= 1900 Jahr)))
+                                (+ Jahr (* 100 (ceiling (- Jahrjetzt Jahr 50)
+                                                        100))))))
+                      ;; 1900-01-01 GMT == 1899-12-31 EST
+                      (<= 1899 Jahr)))
                (and (integerp Monat) (<= 1 Monat 12))
                (progn
                  (if (< Monat 3)
-                   (setq Jahr3 (1- Jahr)  Monat3 (+ Monat 9)) ; Monat3 10..11
-                   (setq Jahr3 Jahr       Monat3 (- Monat 3)) ; Monat3 0..9
-                 )
+                   (setq Jahr3 (1- Jahr)  Monat3 (+ Monat 9))  ; Monat3 10..11
+                   (setq Jahr3 Jahr       Monat3 (- Monat 3))) ; Monat3 0..9
                  (and (and (integerp Tag) (<= 1 Tag))
                       (progn
                         (setq Jahrtag (+ (1- Tag) (Monat->Jahrtag Monat3)))
@@ -751,20 +736,26 @@
                                       (setq Zeitzone
                                         #-(or UNIX WIN32)
                                         (- *default-time-zone*
-                                           (if (funcall *default-dst-check* Jahr3 Jahrtag Stunde) 1 0))
+                                           (if (funcall *default-dst-check*
+                                                        Jahr3 Jahrtag Stunde)
+                                               1 0))
                                         #+(or UNIX WIN32)
-                                        (default-time-zone (+ (* 24 UTTag) Stunde))))
-                                    (when (floatp Zeitzone) (setq Zeitzone (rational Zeitzone)))
+                                        (default-time-zone
+                                            (+ (* 24 UTTag) Stunde) nil)))
+                                    (when (floatp Zeitzone)
+                                      (setq Zeitzone (rational Zeitzone)))
                                     (or (integerp Zeitzone)
-                                        (and (rationalp Zeitzone) (integerp (* 3600 Zeitzone)))))
-                                  (<= -24 Zeitzone 24)))))))
+                                        (and (rationalp Zeitzone)
+                                             (integerp (* 3600 Zeitzone)))))
+                                  (<= -24 Zeitzone 24))
+                             (<= 0 (setq UT (+ Sekunde
+                                               (* 60 (+ Minute
+                                                        (* 60 (+ Stunde Zeitzone
+                                                                 (* 24 UTTag)))))))))))))
     (error-of-type 'error
       (TEXT "incorrect date: ~S-~S-~S ~S:~S:~S, time zone ~S")
       Jahr Monat Tag Stunde Minute Sekunde Zeitzone))
-  (+ Sekunde
-     (* 60 (+ Minute
-              (* 60 (+ Stunde Zeitzone
-                       (* 24 UTTag)))))))
+  UT)
 
 ; (decode-universal-time universal-time [time-zone]), CLTL p. 445
 (defun decode-universal-time (UT &optional (time-zone nil)
@@ -774,14 +765,15 @@
     #-(or UNIX WIN32)
     (setq time-zone *default-time-zone*
           Sommerzeit (let ((UT (- UT (round (* 3600 time-zone)))))
-                       (multiple-value-bind (UTTag Stunde) (floor (floor UT 3600) 24)
+                       (multiple-value-bind (UTTag Stunde) (floor UT (* 3600 24))
                          (multiple-value-bind (Jahr Jahrtag) (Jahr&Tag UTTag)
                            (funcall *default-dst-check* Jahr Jahrtag Stunde))))
-          Zeitzone (- time-zone (if Sommerzeit 1 0)))
+          Zeitzone (if Sommerzeit (1- time-zone) time-zone))
     #+(or UNIX WIN32)
     (progn
-      (multiple-value-setq (Zeitzone Sommerzeit) (default-time-zone (floor UT 3600)))
-      (setq time-zone (+ Zeitzone (if Sommerzeit 1 0)))))
+      (multiple-value-setq (Zeitzone Sommerzeit)
+        (default-time-zone (floor UT 3600) t))
+      (setq time-zone (if Sommerzeit (1+ Zeitzone) Zeitzone))))
   ; time-zone = Zeitzone ohne Sommerzeitberücksichtigung,
   ; Zeitzone = Zeitzone mit Sommerzeitberücksichtigung.
   (let ((UTSekunden (- UT (round (* 3600 Zeitzone)))))
@@ -795,7 +787,8 @@
                 (setq Monat (+ Monat 3)) ; Monat 3..12
                 (setq Monat (- Monat 9) Jahr (+ Jahr 1))) ; Monat 1..2
               (values Sekunde Minute Stunde Tag Monat Jahr (mod UTTage 7)
-                      Sommerzeit time-zone))))))))) ; Ende von macrolet
+                      Sommerzeit time-zone))))))))
+) ; end of macrolet
 
 ; (get-decoded-time), CLTL p. 445
 (defun get-decoded-time ()
