@@ -2,8 +2,8 @@
 ;; (LOOP {loop-clause}*), CLtL2 p. 163,709-747
 ;; <http://www.lisp.org/HyperSpec/Body/sec_6-1.html>
 ;; <http://www.lisp.org/HyperSpec/Body/mac_loop.html>
-;; Bruno Haible 1991-2002
-;; Sam Steingold 1999-2004
+;; Bruno Haible 1991-2004
+;; Sam Steingold 1999-2005
 
 (in-package "COMMON-LISP")
 (export '(loop loop-finish))
@@ -281,9 +281,13 @@
                       :warn-if-needs-rehash-after-gc t
                       :test 'stablehash-eq
                       :initial-contents
-                      '((collect . list) (append . list) (nconc . list)
-                        (sum . sum-count) (count . sum-count)
-                        (maximize . max-min) (minimize . max-min)))))
+                      '((collect . list) (collecting . list)
+                        (append . list) (appending . list)
+                        (nconc . list) (nconcing . list)
+                        (sum . sum-count) (summing . sum-count)
+                        (count . sum-count) (counting . sum-count)
+                        (maximize . max-min) (maximizing . max-min)
+                        (minimize . max-min) (minimizing . max-min)))))
            (eq (gethash kw1 ht) (gethash kw2 ht))))
        (new-accu-var (var clause)
          (let ((others (gethash var accu-table)) bad)
